Centraliser

Time taken by KaTeX to render formulæ : 8 ms PDF version

#### Theorem

If g g g is an element of G=S n G=S_n G=S n​ then C G(g)=⟨g⟩C_G(g)=\langle g\rangle C G​(g)=⟨g⟩ if and only if the cycles of g g g are of unequal coprime lengths.
Alternatively, C G(g)=⟨g⟩C_G(g)=\langle g\rangle C G​(g)=⟨g⟩ if and only if g g g has cycles of coprime length with at most one 1-cycle.
Proof. Since powers of g g g centralise g g g it follows that ⟨g⟩⊆C G(g)\langle g\rangle\subseteq C_G(g)⟨g⟩⊆C G​(g) so
C G(g)=⟨g⟩ ⟺ ∣⟨g⟩∣=∣C G(g)∣ ⟺ ∣g∣=∣C G(g)∣\begin{aligned} C_G(g)=\langle g\rangle\iff \lvert\langle g\rangle\rvert=\lvert C_G(g)\rvert\iff\lvert g\rvert=\lvert C_G(g)\rvert \end{aligned}C G​(g)=⟨g⟩⟺∣⟨g⟩∣=∣C G​(g)∣⟺∣g∣=∣C G​(g)∣​
(1) Let G G G act on itself by conjugation. Then x g x−1=x ⟺ x g=g x xgx^{-1} = x\iff xg=gx xg x−1=x⟺xg=gx so
Stab(g)=C G(g)\begin{aligned} \text{Stab}(g)=C_G(g) \end{aligned}Stab(g)=C G​(g)​
(2)
∣Orb(g)∣=the number of distinct conjugates of g=the number of permutations with the same cycle structure as g\begin{aligned} \lvert \text{Orb}(g)\rvert&=\text{\small the number of distinct conjugates of g}\\ &=\text{\small the number of permutations with the same cycle structure as }g \end{aligned}∣Orb(g)∣​=the number of distinct conjugates of g=the number of permutations with the same cycle structure as g​
Let a a a be the product of the lengths of the cycles of g g g
Let b b b be the number of cycles of equal length.
Let l l l be the least common multiple of the lengths of the cycles, ∣g∣=l≤a\lvert g\rvert=l\leq a∣g∣=l≤a.
Then the number of permutations with the same cycle structure as g g g is
n! a b=∣G∣a b\begin{aligned} \frac{n!}{ab}=\frac{\lvert G\rvert}{ab} \end{aligned}ab n!​=ab∣G∣​​
Hence
∣Orb(g)∣=∣G∣a b\begin{aligned} \lvert \text{Orb}(g)\rvert=\frac{\lvert G\rvert}{ab} \end{aligned}∣Orb(g)∣=ab∣G∣​​
(3) By the Orbit-Stabiliser theorem, ∣Orb(g)∣×∣Stab(g)∣=∣G∣\lvert \text{Orb}(g)\rvert\times\lvert \text{Stab}(g)\rvert=\lvert G\rvert∣Orb(g)∣×∣Stab(g)∣=∣G∣ so by (3)
∣Stab(g)∣=∣G∣∣Orb(g)∣=∣G∣∣G∣/a b=a b≥∣g∣b≥∣g∣=l\begin{aligned} \lvert \text{Stab}(g)\rvert=\frac{\lvert G\rvert}{\lvert \text{Orb}(g)\rvert}=\frac{\lvert G\rvert}{\lvert G\rvert/ab}=ab\geq\lvert g\rvert b\geq\lvert g\rvert=l \end{aligned}∣Stab(g)∣=∣Orb(g)∣∣G∣​=∣G∣/ab∣G∣​=ab≥∣g∣b≥∣g∣=l​
and it follows that
∣Stab(g)∣=∣g∣ ⟺ a=l and b=1\begin{aligned} \lvert \text{Stab}(g)\rvert=\lvert g \rvert\iff a = l \text{ and } b = 1 \end{aligned}∣Stab(g)∣=∣g∣⟺a=l and b=1​
(4) But
a=l ⟺ g has coprime cycle lengths b=1 ⟺ g has unequal cycle lengths\begin{aligned} a=l\iff g\text{ has coprime cycle lengths}\\ b=1 \iff g \text{ has unequal cycle lengths} \end{aligned}a=l⟺g has coprime cycle lengths b=1⟺g has unequal cycle lengths​
(5) (6) The result now follows from (1), (2), (4), (5) and (6).
C G(g)=⟨g⟩ ⟺ ∣Stab(g)∣=∣g∣ ⟺ the cycles of g are of unequal coprime lengths C_G(g)=\langle g\rangle\iff\lvert \text{Stab}(g)\rvert=\lvert g \rvert\iff\text{the cycles of g are of unequal coprime lengths} C G​(g)=⟨g⟩⟺∣Stab(g)∣=∣g∣⟺the cycles of g are of unequal coprime lengths
Cycles of coprime length will have unequal lengths unless they are 1-cycles. Hence we may replace unequal by at most one 1-cycle. ■\blacksquare■